export const description = '在此页面中，我们将查看 Robyn 的未来发展路线图。'

- 添加性能优化
- 集成 Pydantic
- 实现自动常量请求
- 添加 ORM 支持，特别是 Prisma 集成
- 改善插件生态系统
- 改善文档
- 改善 WebSocket 支持
- 添加模板支持
- 集成 GraphQL 与 Strawberry
- 更多地投入到 Robyn 社区建设中

## 下一步

- [高级特性](/documentation/zh/api_reference/advanced-features)
